import { NextResponse } from "next/server";

import { prisma } from "@/lib/prisma";
import { getCurrentUser } from "@/lib/session";

export async function POST(
  req: Request,
  { params }: { params: { id: string } },
) {
  try {
    const user = await getCurrentUser();
    if (!user || user.role !== "ADMIN") {
      return new NextResponse("Unauthorized", { status: 401 });
    }

    const { enabled } = await req.json();

    const authorization = await prisma.authorization.update({
      where: { id: params.id },
      data: { enabled },
    });

    return NextResponse.json(authorization);
  } catch (error) {
    console.error("[AUTHORIZATION_STATUS_UPDATE]", error);
    return new NextResponse("Internal Error", { status: 500 });
  }
}
